==> cms-db_v0.7.9.tar.gz: admin/space.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('space');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_space') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('desc_space') ?></h1>
<h2><?php locale('title_harddisk') ?></h2>
<?php
$free = disk_free_space("../");
$total = disk_total_space("../");
$used = $total - $free;
function formatSize($size, $i = 2) {
	if($size >= 1099511627776) {
		return round($size/1099511627776, $i).' TiB';
	} elseif($size >= 1073741824) {
		return round($size/1073741824, $i).' GiB';
	} elseif($size >= 1048576) {
		return round($size/1048576, $i).' MiB';
	} elseif($size >= 1024) {
		return round($size/1024, $i).' KiB';
	} else {
		return $size.' Bytes';
	}
}
$width = $used/$total*600;
echo '<div style="width: 600px; height: 30px; border: 1px solid #aaa; background: #eee">
	<div style="background: #555; height: 30px; width: '.$width.'px"></div>
</div>';
echo '<p>'.locale('desc_total',true).' '.formatSize($total).'<br />
'.locale('desc_used',true).' '.formatSize($used).'<br />
'.locale('desc_free',true).' '.formatSize($free).'</p>';
?>

</body>
</html>

==> cms-db_v0.7.11.tar.gz: admin/space.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('space');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_space') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css" />
<link rel="stylesheet" type="text/css" href="progressbar.css" />
</head>
<body>

<h1><?php locale('desc_space') ?></h1>
<h2><?php locale('title_harddisk') ?></h2>
<?php
$free = disk_free_space("../");
$total = disk_total_space("../");
$used = $total - $free;
function formatSize($size, $i = 2) {
	if($size >= 1099511627776) {
		return round($size/1099511627776, $i).' TiB';
	} elseif($size >= 1073741824) {
		return round($size/1073741824, $i).' GiB';
	} elseif($size >= 1048576) {
		return round($size/1048576, $i).' MiB';
	} elseif($size >= 1024) {
		return round($size/1024, $i).' KiB';
	} else {
		return $size.' Bytes';
	}
}
include('progressbar.inc.php');
echo '<p style="line-height: 2.25em">';
printProgressBar(25, 'em', '#2784f5', '#ccc', $used/$total);
echo '</p>';
/*$width = $used/$total*600;
echo '<div style="width: 600px; height: 30px; border: 1px solid #aaa; background: #eee">
	<div style="background: #555; height: 30px; width: '.$width.'px"></div>
</div>';*/
echo '<p>'.locale('desc_total',true).' '.formatSize($total).'<br />
'.locale('desc_used',true).' '.formatSize($used).'<br />
'.locale('desc_free',true).' '.formatSize($free).'</p>';
?>

</body>
</html>
